==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/AutoHealCustomActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.AutoHealCustomActionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Custom action to be executed
 * when an auto heal rule is triggered.
 * @property exe Executable to be run.
 * @property parameters Parameters for the executable.
 */
public data class AutoHealCustomActionArgs(
    public val exe: Output<String>? = null,
    public val parameters: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.AutoHealCustomActionArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.AutoHealCustomActionArgs =
        com.pulumi.azurenative.web.inputs.AutoHealCustomActionArgs.builder()
            .exe(exe?.applyValue({ args0 -> args0 }))
            .parameters(parameters?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AutoHealCustomActionArgs].
 */
@PulumiTagMarker
public class AutoHealCustomActionArgsBuilder internal constructor() {
    private var exe: Output<String>? = null

    private var parameters: Output<String>? = null

    /**
     * @param value Executable to be run.
     */
    @JvmName("qbmqwcsxmayhknjm")
    public suspend fun exe(`value`: Output<String>) {
        this.exe = value
    }

    /**
     * @param value Parameters for the executable.
     */
    @JvmName("fcaxbnjfbugstjwo")
    public suspend fun parameters(`value`: Output<String>) {
        this.parameters = value
    }

    /**
     * @param value Executable to be run.
     */
    @JvmName("nrofxyqldsqhxkpi")
    public suspend fun exe(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exe = mapped
    }

    /**
     * @param value Parameters for the executable.
     */
    @JvmName("thjwbdtowckkgsbb")
    public suspend fun parameters(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    internal fun build(): AutoHealCustomActionArgs = AutoHealCustomActionArgs(
        exe = exe,
        parameters = parameters,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/AutoHealCustomActionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.AutoHealCustomActionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Custom action to be executed
 * when an auto heal rule is triggered.
 * @property exe Executable to be run.
 * @property parameters Parameters for the executable.
 */
public data class AutoHealCustomActionArgs(
    public val exe: Output<String>? = null,
    public val parameters: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.AutoHealCustomActionArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.AutoHealCustomActionArgs =
        com.pulumi.azurenative.web.inputs.AutoHealCustomActionArgs.builder()
            .exe(exe?.applyValue({ args0 -> args0 }))
            .parameters(parameters?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [AutoHealCustomActionArgs].
 */
@PulumiTagMarker
public class AutoHealCustomActionArgsBuilder internal constructor() {
    private var exe: Output<String>? = null

    private var parameters: Output<String>? = null

    /**
     * @param value Executable to be run.
     */
    @JvmName("pbankhqkivpdwxgt")
    public suspend fun exe(`value`: Output<String>) {
        this.exe = value
    }

    /**
     * @param value Parameters for the executable.
     */
    @JvmName("vifsmheflarugwtt")
    public suspend fun parameters(`value`: Output<String>) {
        this.parameters = value
    }

    /**
     * @param value Executable to be run.
     */
    @JvmName("mnedqldkogoepxld")
    public suspend fun exe(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.exe = mapped
    }

    /**
     * @param value Parameters for the executable.
     */
    @JvmName("opwjxykewiffoyek")
    public suspend fun parameters(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.parameters = mapped
    }

    internal fun build(): AutoHealCustomActionArgs = AutoHealCustomActionArgs(
        exe = exe,
        parameters = parameters,
    )
}
